from twisted.internet.main import installReactor
from twisted.internet.selectreactor import SelectReactor
from twisted.python import log

import scrapy
from scrapy.crawler import CrawlerProcess


class SelectReactorSubclass(SelectReactor):
    pass


reactor = SelectReactorSubclass()
installReactor(reactor)


class NoRequestsSpider(scrapy.Spider):
    name = "no_request"

    def start_requests(self):
        return []


process = CrawlerProcess(
    settings={
        "TWISTED_REACTOR": "twisted.internet.selectreactor.SelectReactor",
    }
)

d = process.crawl(NoRequestsSpider)
d.addErrback(log.err)
process.start()



import argparse

from scrapy.commands import fetch
from scrapy.utils.response import open_in_browser


class Command(fetch.Command):
    def short_desc(self):
        return "Open URL in browser, as seen by Scrapy"

    def long_desc(self):
        return (
            "Fetch a URL using the Scrapy downloader and show its contents in a browser"
        )

    def add_options(self, parser):
        super().add_options(parser)
        parser.add_argument("--headers", help=argparse.SUPPRESS)

    def _print_response(self, response, opts):
        open_in_browser(response)
